lambeq.ccg2discocat package
===========================

Submodules
----------

lambeq.ccg2discocat.ccg\_parser module
--------------------------------------

.. automodule:: lambeq.ccg2discocat.ccg_parser
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.ccg2discocat.ccg\_rule module
------------------------------------

.. automodule:: lambeq.ccg2discocat.ccg_rule
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.ccg2discocat.ccg\_tree module
------------------------------------

.. automodule:: lambeq.ccg2discocat.ccg_tree
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.ccg2discocat.ccg\_types module
-------------------------------------

.. automodule:: lambeq.ccg2discocat.ccg_types
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.ccg2discocat.ccgbank\_parser module
------------------------------------------

.. automodule:: lambeq.ccg2discocat.ccgbank_parser
   :members:
   :undoc-members:
   :show-inheritance:

lambeq.ccg2discocat.depccg\_parser module
-----------------------------------------

.. automodule:: lambeq.ccg2discocat.depccg_parser
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: lambeq.ccg2discocat
   :members:
   :undoc-members:
   :show-inheritance:
